pub struct FileDataFlags { /* private fields */ }Implementations
Sourceimpl FileDataFlags
impl FileDataFlags
Sourceimpl FileDataFlags
impl FileDataFlags
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl FileDataFlags
impl FileDataFlags
Sourcepub fn compressed(&self) -> <bool as Specifier>::InOut
pub fn compressed(&self) -> <bool as Specifier>::InOut
Returns the value of compressed.
Sourcepub fn compressed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn compressed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of compressed.
#Errors
If the returned value contains an invalid bit pattern for compressed.
Sourcepub fn with_compressed(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_compressed(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of compressed set to the given value.
#Panics
If the given value is out of bounds for compressed.
Sourcepub fn with_compressed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_compressed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of compressed set to the given value.
#Errors
If the given value is out of bounds for compressed.
Sourcepub fn set_compressed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_compressed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of compressed to the given value.
#Panics
If the given value is out of bounds for compressed.
Sourcepub fn set_compressed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_compressed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of compressed to the given value.
#Errors
If the given value is out of bounds for compressed.
Sourcepub fn use_zstd_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn use_zstd_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of use_zstd.
#Errors
If the returned value contains an invalid bit pattern for use_zstd.
Sourcepub fn with_use_zstd(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_use_zstd(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of use_zstd set to the given value.
#Panics
If the given value is out of bounds for use_zstd.
Sourcepub fn with_use_zstd_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_use_zstd_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of use_zstd set to the given value.
#Errors
If the given value is out of bounds for use_zstd.
Sourcepub fn set_use_zstd(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_use_zstd(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of use_zstd to the given value.
#Panics
If the given value is out of bounds for use_zstd.
Sourcepub fn set_use_zstd_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_use_zstd_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of use_zstd to the given value.
#Errors
If the given value is out of bounds for use_zstd.
Sourcepub fn unk_or_err(
&self,
) -> Result<<B30 as Specifier>::InOut, InvalidBitPattern<<B30 as Specifier>::Bytes>>
pub fn unk_or_err( &self, ) -> Result<<B30 as Specifier>::InOut, InvalidBitPattern<<B30 as Specifier>::Bytes>>
Returns the value of unk.
#Errors
If the returned value contains an invalid bit pattern for unk.
Sourcepub fn with_unk(self, new_val: <B30 as Specifier>::InOut) -> Self
pub fn with_unk(self, new_val: <B30 as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of unk set to the given value.
#Panics
If the given value is out of bounds for unk.
Sourcepub fn with_unk_checked(
self,
new_val: <B30 as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_unk_checked( self, new_val: <B30 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of unk set to the given value.
#Errors
If the given value is out of bounds for unk.
Sourcepub fn set_unk(&mut self, new_val: <B30 as Specifier>::InOut)
pub fn set_unk(&mut self, new_val: <B30 as Specifier>::InOut)
Sets the value of unk to the given value.
#Panics
If the given value is out of bounds for unk.
Sourcepub fn set_unk_checked(
&mut self,
new_val: <B30 as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_unk_checked( &mut self, new_val: <B30 as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of unk to the given value.
#Errors
If the given value is out of bounds for unk.